using System.Data;
using System.Data.OleDb;
using System.Windows.Forms;
using C1.Win.C1Command;
using C1.Win.C1FlexGrid;

namespace C1FlexGridAddItemIssue
{
    public partial class MainForm : Form
	{
        enum FormCommands { Refresh, Undo };
        public MainForm()
		{
			InitializeComponent();
        }

        private void LayoutGrid()
        {
            var g = _dataGrid;

            g.Cols["id"].Caption = "ID";
            g.Cols["projecttype"].Caption = "Project";
            g.Cols["generalpartner"].Caption = "Partner";
            g.Cols["businesslawyer"].Caption = "Business Lawyer";
            g.Cols["defenselitigator"].Caption = "Litigator";
            g.Cols["intellectuallawyer"].Caption = "Intellectual Lawyer";
            g.Cols["bankruptcylawyer"].Caption = "Bankruptcy Lawyer";
            g.Cols["adminstaff"].Caption = "Admin";

            g.Cols["generalpartner"].TextAlign = TextAlignEnum.RightCenter;
            g.Cols["businesslawyer"].TextAlign = TextAlignEnum.RightCenter;
            g.Cols["defenselitigator"].TextAlign = TextAlignEnum.RightCenter;
            g.Cols["intellectuallawyer"].TextAlign = TextAlignEnum.RightCenter;
            g.Cols["bankruptcylawyer"].TextAlign = TextAlignEnum.RightCenter;
            g.Cols["adminstaff"].TextAlign = TextAlignEnum.RightCenter;

            g.Cols["generalpartner"].TextAlignFixed = TextAlignEnum.RightCenter;
            g.Cols["businesslawyer"].TextAlignFixed = TextAlignEnum.RightCenter;
            g.Cols["defenselitigator"].TextAlignFixed = TextAlignEnum.RightCenter;
            g.Cols["intellectuallawyer"].TextAlignFixed = TextAlignEnum.RightCenter;
            g.Cols["bankruptcylawyer"].TextAlignFixed = TextAlignEnum.RightCenter;
            g.Cols["adminstaff"].TextAlignFixed = TextAlignEnum.RightCenter;

            g.Cols["id"].Width = 45;
            g.Cols["projecttype"].Width = 150;
            g.Cols["generalpartner"].Width = 55;
            g.Cols["businesslawyer"].Width = 100;
            g.Cols["defenselitigator"].Width = 60;
            g.Cols["intellectuallawyer"].Width = 100;
            g.Cols["bankruptcylawyer"].Width = 115;
            g.Cols["adminstaff"].Width = 50;

            g.AutoSizeRows();
        }

        private void Cmd_mainAddRow_Click(object sender, ClickEventArgs e)
        {
            AddRow();
        }

        private void Cmd_mainUndo_Click(object sender, ClickEventArgs e)
        {
            Undo();
        }

        private void Cmd_mainRefreshData_Click(object sender, ClickEventArgs e)
        {
            RefreshData();
        }

        private void AddRow()
        {
            var g = _dataGrid;

            g.AddItem(new object[0]);
        }

        private void Undo()
        {
            ReloadData(FormCommands.Undo);
            if(Cmd_mainRefreshData.Text == "Refresh Data")
            {
                Cmd_mainRefreshData.Text = "Load Data";
            }
        }

        private void RefreshData()
        {
            ReloadData(FormCommands.Refresh);
            if(Cmd_mainRefreshData.Text == "Load Data")
            {
                Cmd_mainRefreshData.Text = "Refresh Data";
            }
        }

        private void ReloadData(FormCommands command)
        {
            string query = string.Empty;
            if(command == FormCommands.Refresh)
            {
                query = "select * from ProjectType order by id";
            }
            else if(command == FormCommands.Undo)
            {
                query = "select * from ProjectType where 1 = 2 order by id";
            }

            LoadData(query);
            LayoutGrid();
        }

        private void LoadData(string query)
        {
            var g = _dataGrid;

            using(var connection = new OleDbConnection(Program.DBConnectionString))
            {
                connection.Open();

                using(var command = new OleDbCommand(query, connection))
                using(var adapter = new OleDbDataAdapter(command))
                using(var table = new DataTable())
                {
                    adapter.Fill(table);

                    g.DataSource = table.Copy();
                }

                connection.Close();
            }
        }
    }
}